This crate contains kube-rs compatible bindings for Kubernetes custom resources for the config.gatekeeper.sh group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
config.gatekeeper.sh/v1alpha1
Config